import React, { FC, useEffect, useState } from 'react';
import { View, StyleSheet } from 'react-native';
import { NavigationProp } from '@react-navigation/native';
import { PageWrapper, Header, Input } from 'src/components';
import { FlashList } from '@shopify/flash-list';

import SearchIcon from 'assets/icons/search.svg';
import { applyModalSort, dataRanking } from '../../TravellersScreen/utils';
import { RankingDropdown } from '../../TravellersScreen/utils/types';
import { Profile } from '../../MapScreen/UsersListScreen/Profile';
import { FilterButton, FilterModal } from '../../TravellersScreen/Components/FilterModal';
import { usePostGetCountriesRanking } from '@api/ranking';

type Props = {
  navigation: NavigationProp<any>;
  route: any;
};

const ParticipantsListScreen: FC<Props> = ({ navigation, route }) => {
  const { participants } = route.params;
  const { data: masterCountries } = usePostGetCountriesRanking();

  const [searchQuery, setSearchQuery] = useState('');
  const [filteredData, setFilteredData] = useState<any[]>([]);
  const [confirmedValueRanking, setConfirmedValueRanking] = useState<RankingDropdown | null>();
  const [isModalVisible, setModalVisible] = useState(false);

  useEffect(() => {
    if (participants) {
      setFilteredData(participants);
    }
  }, [participants]);

  const handleSearch = (text: string) => {
    if (text && participants) {
      const searchData =
        participants?.filter((item: any) => {
          const itemData = item.first_name
            ? item.first_name.toLowerCase() + ' ' + item.last_name?.toLowerCase()
            : ''.toLowerCase();
          const textData = text.toLowerCase();
          return itemData.indexOf(textData) > -1;
        }) ?? [];
      setFilteredData(searchData);
      setSearchQuery(text);
    } else {
      setFilteredData(participants ?? []);
      setSearchQuery(text);
    }
  };

  return (
    <PageWrapper>
      <Header
        label="Participants"
        rightElement={<FilterButton onPress={() => setModalVisible(!isModalVisible)} />}
      />
      <View style={styles.container}>
        <Input
          inputMode={'search'}
          placeholder={'Search nomads'}
          onChange={handleSearch}
          value={searchQuery}
          icon={<SearchIcon fill={'#C8C8C8'} width={14} height={14} />}
        />
        <FlashList
          viewabilityConfig={{
            waitForInteraction: true,
            itemVisiblePercentThreshold: 50,
            minimumViewTime: 1000
          }}
          estimatedItemSize={50}
          data={filteredData || []}
          renderItem={({ item, index }) => (
            <Profile
              userId={item.user_id}
              key={index}
              index={index}
              first_name={item.first_name}
              last_name={item.last_name}
              avatar={item.avatar ? '/img/avatars/' + item.avatar : null}
              date_of_birth={item.age}
              homebase_flag={'/img/flags_new/' + item.flag1}
              homebase2_flag={item.flag2 ? '/img/flags_new/' + item.flag2 : null}
              score={[
                item.score_nm,
                item.score_un,
                item.score_unp,
                item.score_dare,
                item.score_tcc,
                item.score_deep,
                item.score_slow,
                item.score_yes,
                item.score_kye,
                item.score_whs,
                item.score_tbt
              ]}
              active_score={
                confirmedValueRanking ? confirmedValueRanking.value - 1 : dataRanking[0].value - 1
              }
              tbt_score={item.score_tbt}
              tbt_rank={item.rank_tbt}
              badge_tbt={item.badge_tbt}
              badge_1281={item.badge_1281}
              badge_un={item.badge_un}
              badge_un_25={item.badge_un_25}
              badge_un_50={item.badge_un_50}
              badge_un_75={item.badge_un_75}
              badge_un_100={item.badge_un_100}
              badge_un_150={item.badge_un_150}
              auth={item.auth}
            />
          )}
          keyExtractor={(item) => item.user_id.toString()}
          contentContainerStyle={{ paddingBottom: 16, paddingTop: 8 }}
          showsVerticalScrollIndicator={false}
        />
      </View>

      <FilterModal
        isModalVisible={isModalVisible}
        setModalVisible={(value) => setModalVisible(value)}
        applyFilter={(filterAge, filterRanking, filterCountry) => {
          setConfirmedValueRanking(filterRanking);
          setFilteredData(
            applyModalSort(
              participants ?? [],
              filterAge,
              filterRanking ?? dataRanking[0],
              filterCountry
            )
          );
          setModalVisible(false);
        }}
        countriesData={masterCountries ? masterCountries.data : []}
      />
    </PageWrapper>
  );
};

const styles = StyleSheet.create({
  container: {
    backgroundColor: 'white',
    gap: 16,
    flex: 1
  }
});

export default ParticipantsListScreen;
